##  Enter the Necessary Credentials in SAP LeanIX
  1. Add the Zscaler integration in SAP LeanIX. For more, see [Setting Up Out-of-the-Box Integrations](https://help.sap.com/docs/leanix/ea/discovery-and-integrations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ba7437a441014af4ea67e4bf11105__setting_up_out-of-the-box_integrations).
  2. In the configuration, choose a name for the integration and the type of capabilities or data you want to get from Zscaler.
  3. Enter the credentials from the ZIA portal that you have generated into the corresponding fields:
    1. API URL: URL where your Zscaler instance is deployed (e.g., https://zsapi.zscalerthree.net).
    2. Username: Username created and used on the ZIA portal.
    3. Password: Password of the user created on the ZIA portal.
    4. API Key: API key generated on the ZIA portal.


![Configuring Integration of Zscaler in SAP LeanIX](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751c37b7a441014a7e0bdde23aa17b3_LowRes.png)
Configuring Integration of Zscaler in SAP LeanIX
  1. Click Finish and wait for the connection to be established.
